""" Tops context is the numeric context obtained from reading Tops files
"""

from geo.data.log_context import LogContext

class TopsContext(LogContext):
    """ Log Context that is specific to Tops data

        Equivalent of TopsGroup
    """

    #---------------------------------------------------------------------------
    #   HasTraits Interface
    #---------------------------------------------------------------------------

    ### protected methods ------------------------------------------------------

    def __getstate__(self):
        """
        Return the state of this object for pickling.

        Extended to remove transient traits, and also store version information.

        """

        # Obtain state from base class(es)
        state =  super(TopsContext, self).__getstate__()

        # Add in our current version number.  Note use a different attribute
        # name from any base or derived class so that our numbers don't
        # override theirs.
        state['_tops_context_version'] = 1

        return state


    def __setstate__(self, state):
        """
        Restore the state of this object during unpickling.

        Extended to handle version upgrades.

        """

        # Get the version info out of the state dictionary.
        version = state.pop('_tops_context_version', 0)

        # Resetting the index of the TopsContext
        # Check if the state dictionary already contains '__index' key
        if not state.has_key('__index'):
            state['__index'] = ''

        # Upgrade to version 1.
        if version < 1 and state['__index']=='':
            # Include dynamic bindings to all the numeric contexts in the
            # dictionary
            items_dict = {}

            if state.has_key('context_data'):
                context_data = state['context_data']
                if isinstance(context_data, dict) and len(context_data) > 0:
                    items_dict = state['context_data']._dict

            for k,v in items_dict.items():
                if v.units and v.units.derivation == (1,0,0,0,0,0,0):
                    state['__index'] = k
                    break

        # Restore the base class's state.
        super(TopsContext, self).__setstate__(state)
        return


### EOF ------------------------------------------------------------------------

