# Enthought library imports
from enthought.traits.api import HasTraits, Str

class ILogReader(HasTraits):
    """ Interface definition for LogReader classes.

        Concrete implementations of this class are used by LogReaderUI
        and others to read in log data from different sources.  Concrete
        implementation include LasLogReader and TabLogReader.
    """

    # Filter for the types of files this reader can read.
    # fixme: A database wouldn't have this.  Do we want a separate
    #        IFileLogReader interface just to add this?
    file_filter = Str

    def read_info(self, source):
        """ Return an ILogReaderInfo object from the source.

        """
        raise NotImplementedError

    def read_data(self, source, log_reader_info):
        """ Return a context filled with the data read from 'source'.

            log_reader_info is an ILogReaderInfo object that
            describes which logs from the source should be read, whether their
            units should be converted, etc.
        """
        raise NotImplementedError
