# Standard library imports.
import logging

# Enthought library imports
from enthought.traits.api import HasTraits, Str, Any, List, Instance

# Local imports
from log_conversion_info_item import LogConversionInfoItem


logger = logging.getLogger(__name__)


class ILogReaderInfo(HasTraits):
    """ Holds useful information aboud the data available in a log source.
    """

    # The source location of the data.
    # For files, this could be a file name.  For a database, it could be a
    # query object.
    source = Any('')

    # Name of the well.
    well_name = Str

    # Value used to represent Nulls in the data.
    null_value = Any

    # List describing the logs available in the source
    # It also describes which logs should be loaded, unit conversion, etc.
    log_info = List(LogConversionInfoItem)

    def trait_view(self, name=None, view_element=None):
        if name is None and view_element is None:
            # Import in here such that non-UI code does not require wx.
            from geo.io.ui.log_reader_view import log_reader_info_view
            return log_reader_info_view
        else:
            super(ILogReaderInfo, self).trait_view(name=name, view_element=view_element)

    def _well_name_changed(self, old, new):
        logger.debug('ILogReaderInfo [%s] detected well_name changed from [%s] to [%s]', self, old, new)

        return
