""" Read in a LAS file and create a new NumericContext.
"""

# Geo imports
from geo.io.log_file_reader import LogFileReader
from geo.io.las.las_header import LasHeader

class LasLogReader(LogFileReader):
    """ Read in the data from a Las File based on the LasHeader
    """

    ############################################################################
    # 'ILogReader' interface.
    ############################################################################

    ### Public traits ##########################################################

    file_filter = 'LAS files (*.las)|*.las'

    ############################################################################
    # 'LogFileReader' interface.
    ############################################################################

    ### Public traits ##########################################################

    header_class = LasHeader

    ### Public methods #########################################################

    def seek_to_data(self, file):
        """ Seek to the line where the data in the Las File.
        """

        while True:
            line = file.readline()
            if line[:2] == '~A':
                break

        return


    # fixme: this is the old version of the seek_to_data routine.
    # file handling doesn't seem right with this one.
    def seek_to_data_old(self, file):
        """ Seek to the line where the data in the Las file.
        """

        # Used to keep track of byte position of the start of the next line.
        last_position = 0

        # Have we read the last section yet?
        last_section = False

        # fixme: This code is almost a duplicate of the code in LasHeader.
        #        refactor.
        # loop until we get to the end of the header
        while True:
            last_position = file.tell()
            line = file.readline()
            if len(line) == 0:
                #fixme: We reached the end of the file without finding any data.
                #       We should handle this gracefully.
                pass
            elif last_section and not line.startswith('#'):
                # we're done!
                break
            elif line[:2] == "~A" or line == '':
                # We're at the beginning of the last section.
                # signal to stop grabbing lines once this section is finished.
                last_section = True


        # move to the next line where data starts
        file.seek(last_position)


