#!/usr/bin/env python
#-----------------------------------------------------------------------------
#
#  Copyright (c) 2007 by Enthought, Inc.
#  All rights reserved.
#
#-----------------------------------------------------------------------------

""" Python setup for geo.io.las package
"""

def configuration(parent_package='geo.io',top_path=None):
    from numpy.distutils.misc_util import Configuration
    config = Configuration('las',parent_package,top_path)


    def build_write_array(extension, build_dir):
        from numpy import zeros, uint32, int32, float32, float64, complex64, complex128
        import scipy, os, sys
        from weave import ext_tools

        target = os.path.join(build_dir,'_write_array.cpp')

        mod = ext_tools.ext_module('_write_array')
        
        # build a C statement that can write out a 2D array quickly.
        # it allows the user to specify a format string for each array element,
        # an element separator, and a line separator.  While this is
        # useful for las files, it is also fairly generically applicable.
        code = 'int element_size = sizeof(*ary);                     \n' \
               'int row_offset = Sary[0]/element_size;               \n' \
               'int col_offset = Sary[1]/element_size;               \n' \
               '                                                     \n' \
               '%(type)s* row = (%(type)s*) ary;                     \n' \
               'for (int i=0;i<Nary[0];i++)                          \n' \
               '{                                                    \n' \
               '    %(type)s* element = row;                         \n' \
               '    for (int j=0;j<Nary[1];j++)                      \n' \
               '    {                                                \n' \
               '        fprintf(file, format.c_str(), %(element)s);  \n' \
               '        fprintf(file, element_separator.c_str());    \n' \
               '        element += col_offset;                       \n' \
               '    }                                                \n' \
               '    fprintf(file, line_separator.c_str());           \n' \
               '    row += row_offset;                               \n' \
               '}                                                    \n'

        # make the dummy variables that supply type information
        format = "%12.3f"
        element_separator = ""
        line_separator = "\n"
        import tempfile
        file = open(tempfile.mktemp(),'w')

        # we'll build one for float, double, complex and double complex.
        # all other formats are converted to double in write_array.py
        versions = [(int32, 'int', 'i', '*element'),
                    (uint32, 'unsigned int', 'ui', '*element'),
                    (float32, 'float', 'f', '*element'),
                    (float64, 'double', 'd', '*element'),
                    (complex64, 'std::complex<float>', 'F', 'element->real(),element->imag()'),
                    (complex128, 'std::complex<double>', 'D', 'element->real(),element->imag()')]
        
        for typecode, type, func_suffix, element in versions:
            code_kw = {}
            code_kw['element'] = element
            code_kw['type'] = type
                                    
            ary = zeros((2,2), typecode)
            func_name = "write_array_"+func_suffix
            func = ext_tools.ext_function(func_name,code % code_kw, 
                                          ['file','ary','format',
                                           'element_separator', 'line_separator'])
            mod.add_function(func)

        file.close()
    
        mod.generate_file(location=build_dir)

        info = mod.build_information()
        extension.include_dirs.extend(info.include_dirs())    

        return [target] + info.sources()

    config.add_extension('_write_array',[build_write_array])

    return config
