""" This class adapts a LasHeader item to the ILogReaderInfo interface.  It
    is used by tools that want to examine information about a data source
    without having to no what type the data source is.

    fixme: Should this be named Adapter then...?
"""

# Standard library imports
import logging

# Enthought library imports
from enthought.traits.api import Instance

# Geo library imports
from geo.io.api import ILogReaderInfo

# Local imports
from geo.io.log_file_header_base import LogFileHeaderBase


logger = logging.getLogger(__name__)


class LogFileHeaderToLogReaderInfoAdapter(ILogReaderInfo):
    """
    Holds useful information aboud the data available in a log source.

    """

    # An underlying LasHeader object that provides most of our information.
    header = Instance(LogFileHeaderBase)

    ############################################################################
    # LasReaderInfo interface.
    ############################################################################

    ### trait change listeners #################################################

    def _header_changed(self, old, new):
        """
        When the las header is set, update other values to match.

        """
        logger.debug('LogFileHeaderToLogReaderInfoAdapter [%s] detected header changed from [%s] to [%s]', self, old, new)

        self.null_value = new.null_value
        self.well_name = new.well_name

        # this is the key --- converting the las header log info to
        # to a list of LogConversionInfoItems.
        self.log_info = new.log_conversion_info()



