""" ParameterInfoItem is a simple data structure for storing information
    about parameters found in well log storage files.

    Note: This was originally just used by the LAS reader, but was refactored
          here because it was useful for the tabbed reader as well.
"""

# Enthought Library Imports
from enthought.traits.api import HasTraits, Str

# Geo lirbary imports
from geo.io.api import LogConversionInfoItem

class ParameterInfoItem(HasTraits):
    """ Simple data structure for storing parameters found in a file headers.
    """

    #### 'LasInfoItem' interface ###############################################

    # Name of the log/curve
    name = Str

    # Text description of the log such as "primary velocity in shale"
    description = Str

    # String, such as "m/s", that can be parsed by the enthought.units.parser
    units = Str

    # data holds the value for the parameter in string format.
    # This may be empty.
    data = Str

    ############################################################################
    # 'LasInfoItem' interface.
    ############################################################################

    #### class methods #########################################################

    @classmethod
    def from_las_header_string(cls, string):
        """ Factory to generate LogInfo objects from a string in LAS format.

            This method parses a line from a las header and returns a
            LasInfoItem object that represents it.
        """

        # everything before the first '.' is the MNEM
        name, remainder = string.split( '.', 1 )
        name = name.strip()

        # Next come the units.
        units, remainder = remainder.split( ' ', 1 )
        units = units.strip()

        # finally extract [DATA|VALUE|API CODE]
        data, remainder = remainder.split(':', 1)
        data = data.strip()

        # anything after the ':' is the 'description'
        description = remainder.strip()

        return cls(name=name, description=description,
                   units=units, data=data)

    def as_log_conversion_info_item(self):
        return LogConversionInfoItem(input_name=self.name,
                                     input_units=self.units,
                                     desired_name=self.name,
                                     desired_units=self.units,
                                     description=self.description)


    ############################################################################
    # 'object' interface.
    ############################################################################

    def __repr__(self):
       return '%10s %20s %-10s %-30s' % (self.name, self.data, self.units,
                                         self.description[:30])
