""" Reads an external, tab delimited, text data file containing
numeric or text logs and returns a log suite containing all logs.

Description
-----------
The first line must be tab-separated log names.  The second line in the
file must be tab-separated log units.  Units for text based logs may be
'' (single quotes), "" (double quotes), or _ (underscore) to indicate
missing units.

The first column in the data file is assumed to be the index or reference.
Remaining columns may be either real or text logs.

Log names and units are converted to lower case.  Text log values are not
converted to lower case.

Multi-channel logs (ie. logs with multiple values at a single depth) may
not be input using this tab-delimited module.

Missings
--------
Missing log values for text based logs, such as tops or markers, may be
denoted by '' (single quotes), "" (double quotes), or _ (underscore) in
the ASCII input file.

Any missings found in text based logs are not removed.

Missing values for numeric logs must be denoted by a value of -999.25,
'NaN', or 'nan' (without the quotes).  Any missings found in numeric
logs are not removed but their values are changed to NaN.

Input Examples
--------------
1) Checkshots::

    depth_cks   time_cks
    feet    msec
    1810.35  400.
    1861.54  430.
    1912.48  450.
    1963.33  460.

2) Tops::

    depth   TOPS        Phi
    feet    ''          v/v
    3700.   Top Red     .265
    3900.   Base Unkn   .245
    5498.   _           .121
    6500.   Cret. Uncf  .278
    12250.  Base Blue   .231
    13000.  TD        -999.25
"""