""" Class for reading information about logs from a tab delimited file.
    See the __init__.py file in package for more information.
"""
# Enthought library imports
from enthought.traits.api import List

# Geo library imports
from geo.io.log_file_header_base import LogFileHeaderBase
from geo.io.parameter_info_item import ParameterInfoItem
from geo.io.util import load_header_for_delimited_files

class TabbedLogHeader(LogFileHeaderBase):
    """ Read the header information about curves from a tab-delimited file.
    """

    #### 'TabbedLogHeader' interface ###########################################

    # String interpreted as having no units.
    _unitless_strings = List(["''", '""', '_'])

    ############################################################################
    # Protected 'LogFileHeaderBase' interface.
    ############################################################################

    @staticmethod
    def _load_header(file):
        """ Return a list (name, unit) pairs for each of the logs in the file.
        """
        return load_header_for_delimited_files(file, '\t', False)


    def _process_header(self, records):
       """ Convert a list of (name, unit) string pairs to our internal
           LogInfo representation.
       """

       # Zip is its own inverse.  This actually unzips a list of (name,unit)
       # pairs into two lists of names, units.  We need u
       names, units = zip(*records)

       # strip any whitespace from each string.
       names = [name.strip() for name in names]
       units = [unit.strip() for unit in units]

       # Replace any occurance of '', "", or '_' with a None
       for i, unit in enumerate(units):
           if unit in self._unitless_strings or unit.lower() == 'none':
               units[i] = ''

       self.log_info = [ParameterInfoItem(name=name, units=units)
                        for name, units in zip(names, units)]

       return
