""" Class for reading the reader of Tops files

    This is a subclass of WhitespaceLogReader
"""

# Geo library imports
from geo.io.whitespace_log.whitespace_log_reader import WhitespaceLogReader
from geo.io.util import InvalidDataError
from geo.data.tops_context import TopsContext

class TopsLogReader(WhitespaceLogReader):
    """ Class for reading data of Tops files

        It handles unit_family of the LogConversionInfoItem specifically for
        Tops files, in the read_info method.
        It returns a NumericContext in the read_data method
    """

    has_string_data = True

    def read_info(self, source):
        """ Returns a an object with ILogReaderInfo interface.

            'source' is either a file path or a file object.  If it is a file
            object, the 'source' traits in the returned  object
            is set to ''.

            It calls the method definition in its super-class, i.e.,
            LogFileReader.

            We make sure it has only 2 'logs'.
        """
        info = super(TopsLogReader, self).read_info(source)
        if len(info.log_info) != 2:
            raise InvalidDataError

        return info

    def read_data(self, source, conversion_info):
        """ Return a numeric context from data file

            Parameters:
            -----------
            source: Str or File
                name of file or the file itself, which contains the data
            conversion_info: LogFileHeaderToLogReaderInfoAdapter
                contains information about the conversions between inputs
                and desired metadata

            Returns:
            --------
            context: NumericContext
        """

        if len(conversion_info.log_info) != 2:
            raise InvalidDataError
        result =  super(TopsLogReader, self).read_data(source, conversion_info)

        topscontext = TopsContext()
        for k,v in result.items():
            topscontext.set_dotted(str(k), v)

        return topscontext

