#-----------------------------------------------------------------------------
#
#  Copyright (c) 2007 by Enthought, Inc.
#  All rights reserved.
#
#-----------------------------------------------------------------------------

""" Dropd-down editor for "units" column in a table.

    This editor allows a person to type in a set of units.  It
    also allows them to choose from a drop down of common units.

    fix me: This list should be about 10 long.  It should key off
            of the set of units currently in the cell (or off of
            a list linked to by the developer that may come from
            family name settings in another table cell).  At the
            end it should have "Other...".  Choosing this would
            pop-up an even longer more comprehensive list.  Of
            course, the user should always be able to by-pass the
            drop down and just type the units into the cell.


    fixme: Currently, this is useless outside of geophysics (and
           perhaps outside of our apps) because of the use of log_info
           singleton object.  This really needs to be configurable
           setup so that people can add new "unit systems" on the
           fly and customize things for other disciplines...
"""

# Enthought Library Imports
from enthought.traits.api import Color
from enthought.traits.ui.api import EnumEditor
from enthought.traits.ui.table_column import ObjectColumn

# fixme: We very much need to move away from these singleton things...
from log_info import log_info

WARNING_COLOR = (255, 242, 0)
ERROR_COLOR = (255, 122, 122)

def get_unique_unit_names():
    """
    """
    units = {}
    for row in log_info.log_names:
        for col in log_info.column_names:
           if col.endswith("_UNITS"):
               unit = log_info(row, col)
               units[unit.get_label()] = ""

    unique = units.keys()
    unique.append('percentage')

    unique.sort()
    return unique

class UnitsColumn(ObjectColumn):
    """ Column specialized for units in a LasConversionInfo table row.

        This column is coupled to the LasConversionInfo class
        because it knows about and uses the "units_status" trait.
    """

    error_color = Color(ERROR_COLOR)
    warning_color = Color(WARNING_COLOR)

    def get_cell_color(self, object):

        # check for incompatible units
        if object.units_status == 'warning':
           color = self.warning_color
        elif object.units_status == 'error':
           color = self.error_color
        else:
           color = super(UnitsColumn, self).get_cell_color(object)

        return color

    def get_editor(self, object):
        return EnumEditor(values = get_unique_unit_names(),
                          evaluate = str)
